import prisma from '../utilities/Prisma'; // Import the global Prisma instance
import {Character} from '@prisma/client';
import CharacterService from "../services/CharacterService";

class CharacterRepository {
    async getByUserId(userId: number): Promise<Character[] | null> {
        try {
            return await prisma.character.findMany({
                where: {
                    userId,
                },
            });
        } catch (error: any) {
            // Handle error
            throw new Error(`Failed to get character by user ID: ${error.message}`);
        }
    }

    async create(userId: number, name: string): Promise<Character | null> {
        try {
            return await prisma.character.create({
                data: {
                    userId,
                    name,
                    position_x: 0,
                    position_y: 0,
                    rotation: 0,
                    zoneId: 1,
                },
            });
        } catch (error: any) {
            // Handle error
            throw new Error(`Failed to create character: ${error.message}`);
        }
    }
}

export default new CharacterRepository;